| Title: | A tool to identify potentially oncogenic genes |
|---|---|
| Description: | OncoScore is a tool to measure the association of genes to cancer based on citation frequencies in biomedical literature. The score is evaluated from PubMed literature by dynamically updatable web queries. |
| Authors: | Luca De Sano [cre, aut] (ORCID: <https://orcid.org/0000-0002-9618-3774>), Carlo Gambacorti Passerini [ctb], Rocco Piazza [ctb], Daniele Ramazzotti [aut] (ORCID: <https://orcid.org/0000-0002-6087-2666>), Roberta Spinelli [ctb] |
| Maintainer: | Luca De Sano <[email protected]> |
| License: | file LICENSE |
| Version: | 1.41.0 |
| Built: | 2026-05-30 07:19:11 UTC |
| Source: | https://github.com/bioc/OncoScore |
Merge a set of genes in a unique one in order to account for possible aliases
combine.query.results(query, genes, new.name)combine.query.results(query, genes, new.name)
query |
The result of perform.query, perform.query.timeseries of perform.query.from.region |
genes |
A list of genes to be merged |
new.name |
A string containing the new name to be used for the new genes |
The frequencies of the genes in the cancer related documents and in all the documents retireved on PubMed
data(query) combine.query.results(query, c('IDH1', 'IDH2'), 'new_gene')data(query) combine.query.results(query, c('IDH1', 'IDH2'), 'new_gene')
Perform merge procedure on a matrix
combine.single.matrix(query, genes, new.name)combine.single.matrix(query, genes, new.name)
query |
The result of perform.query, perform.query.timeseries of perform.query.from.region |
genes |
A list of genes to be merged |
new.name |
A string containing the new name to be used for the new genes |
a merged matrix
compute the logaritmic scores based on the frequencies of the genes
compute.frequencies.scores(data, filter.threshold = 1, analysis.mode = "Log2")compute.frequencies.scores(data, filter.threshold = 1, analysis.mode = "Log2")
data |
input data as result of the function perform.query |
filter.threshold |
threshold to filter for a minimum number of citations for the genes |
analysis.mode |
logaritmic scores to be computed, i.e., log10, log2, natural log or log5 |
the computed scores
compute the OncoScore for a list of genes
compute.oncoscore( data, filter.threshold = 0, analysis.mode = "Log2", cutoff.threshold = 21.09, file = NULL, filter.invalid = TRUE )compute.oncoscore( data, filter.threshold = 0, analysis.mode = "Log2", cutoff.threshold = 21.09, file = NULL, filter.invalid = TRUE )
data |
input data as result of the function perform.query |
filter.threshold |
threshold to filter for a minimum number of citations for the genes |
analysis.mode |
logaritmic scores to be computed, i.e., log10, log2, natural log or log5 |
cutoff.threshold |
threshold to be used to asses the oncogenes |
file |
should I save the results to text files? |
filter.invalid |
auto-remove genes with invalid count |
the computed OncoScores and the clusters for the genes
data(query) compute.oncoscore(query)data(query) compute.oncoscore(query)
Perform OncoScore analysis on a given chromosomic region
compute.oncoscore.from.region( chromosome, start = NA, end = NA, gene.num.limit = 100, filter.threshold = NA, analysis.mode = "Log2", cutoff.threshold = 21.09, file = NULL )compute.oncoscore.from.region( chromosome, start = NA, end = NA, gene.num.limit = 100, filter.threshold = NA, analysis.mode = "Log2", cutoff.threshold = 21.09, file = NULL )
chromosome |
chromosome to be retireved |
start |
initial position to be used |
end |
final position to be used |
gene.num.limit |
A limit to the genes to be considered in the analysis; this is done to limit the number of queries to PubMed |
filter.threshold |
threshold to filter for a minimum number of citations for the genes |
analysis.mode |
logaritmic scores to be computed, i.e., log10, log2, natural log or log5 |
cutoff.threshold |
threshold to be used to asses the oncogenes |
file |
should I save the results to text files? |
the computed scores
chromosome = 15 start = 200000 end = 300000chromosome = 15 start = 200000 end = 300000
perform the OncoScore time series analysis for a list of genes and data times
compute.oncoscore.timeseries( data, filter.threshold = 0, analysis.mode = "Log2", cutoff.threshold = 21.09, file = NULL )compute.oncoscore.timeseries( data, filter.threshold = 0, analysis.mode = "Log2", cutoff.threshold = 21.09, file = NULL )
data |
input data as result of the function perform.query.timeseries |
filter.threshold |
threshold to filter for a minimum number of citations for the genes |
analysis.mode |
logaritmic scores to be computed, i.e., log10, log2, natural log or log5 |
cutoff.threshold |
threshold to be used to asses the oncogenes |
file |
should I save the results to text files? |
the performed OncoScores time series analysis
data(query.timepoints) compute.oncoscore.timeseries(query.timepoints)data(query.timepoints) compute.oncoscore.timeseries(query.timepoints)
estimate the oncoscore for the genes
estimate.oncogenes(data, cutoff.threshold = 21.09)estimate.oncogenes(data, cutoff.threshold = 21.09)
data |
input data as result of the function compute.frequencies.scores |
cutoff.threshold |
threshold to be used to asses the oncogenes |
the computed scores and oncogenes
This dataset contains a list of genes to be used in the analysis as an example
data(genes)data(genes)
rdata
list of 5 elements
example data
Get a gene list from biomart
get.genes.from.biomart(chromosome, start = NA, end = NA)get.genes.from.biomart(chromosome, start = NA, end = NA)
chromosome |
chromosome to be retireved |
start |
initial position to be used |
end |
final position to be used |
A list of genes
chromosome = 15 start = 200000 end = 300000chromosome = 15 start = 200000 end = 300000
process the result of the query
get.list.from.xml(webget)get.list.from.xml(webget)
webget |
The result from the query to PubMed |
Processed result obtained from the query to PubMed
query PubMed for a list of genes
get.pubmed.driver.analysis(keywords, gene)get.pubmed.driver.analysis(keywords, gene)
keywords |
The set of keywords to be used for the query to PubMed |
gene |
The name of a gene to be used for the query to PubMed |
The frequency for the current gene retrieved with the query on the provided set of keywords
perforn the query to PubMed
perform.query(list.of.genes, gene.num.limit = 100, custom.search = NA)perform.query(list.of.genes, gene.num.limit = 100, custom.search = NA)
list.of.genes |
The list of genes to be used in the queries to PubMed |
gene.num.limit |
A limit to the genes to be considered in the analysis; this is done to limit the number of queries to PubMed |
custom.search |
A custom set of keyworkds to be used when quering PubMed |
The frequencies of the genes in the cancer related documents and in all the documents retireved on PubMed
data(genes)data(genes)
Perform the query to PubMed on a given chromosomic region
perform.query.from.region( chromosome, start = NA, end = NA, gene.num.limit = 100 )perform.query.from.region( chromosome, start = NA, end = NA, gene.num.limit = 100 )
chromosome |
chromosome to be retireved |
start |
initial position to be used |
end |
final position to be used |
gene.num.limit |
A limit to the genes to be considered in the analysis; this is done to limit the number of queries to PubMed |
The frequencies of the genes in the cancer related documents and in all the documents retireved on PubMed
chromosome = 15 start = 200000 end = 300000chromosome = 15 start = 200000 end = 300000
perforn the query to PubMed for the time series analysis
perform.query.timeseries( list.of.genes, list.of.datatimes, gene.num.limit = 100, timepoints.limit = 10, custom.search = NA )perform.query.timeseries( list.of.genes, list.of.datatimes, gene.num.limit = 100, timepoints.limit = 10, custom.search = NA )
list.of.genes |
The list of genes to be used in the queries to PubMed |
list.of.datatimes |
The list of time points to be used in the queries to PubMed |
gene.num.limit |
A limit to the genes to be considered in the analysis; this is done to limit the number of queries to PubMed |
timepoints.limit |
A limit to the time points to be considered in the analysis; this is done to limit the number of queries to PubMed |
custom.search |
A custom set of keyworkds to be used when quering PubMed |
The frequencies of the genes in the cancer related documents and in all the documents retireved on PubMed at the specified time points
data(genes) data(timepoints)data(genes) data(timepoints)
plot the OncoScore for a list of genes
## S3 method for class 'oncoscore' plot( x, gene.number = 5, main = "OncoScore", xlab = "score", ylab = "genes", file = NA, ... )## S3 method for class 'oncoscore' plot( x, gene.number = 5, main = "OncoScore", xlab = "score", ylab = "genes", file = NA, ... )
x |
input data as result of the function compute.OncoScore |
gene.number |
number of genes to print |
main |
the title |
xlab |
description of x asix (defaul score) |
ylab |
description of y asix (defaul genes) |
file |
where to save the plot |
... |
additional parameter to pass to the barplot function |
A plot
data(query) result = compute.oncoscore(query) plot.oncoscore(result)data(query) result = compute.oncoscore(query) plot.oncoscore(result)
plot the OncoScore for a list of genes
## S3 method for class 'oncoscore.timeseries' plot( x, gene.number = 5, incremental = FALSE, relative = FALSE, main = "OncoScore", xlab = "timepoints", ylab = "score", legend.pos = "top", file = NA, ... )## S3 method for class 'oncoscore.timeseries' plot( x, gene.number = 5, incremental = FALSE, relative = FALSE, main = "OncoScore", xlab = "timepoints", ylab = "score", legend.pos = "top", file = NA, ... )
x |
input data as result of the function compute.OncoScore |
gene.number |
number of genes to print |
incremental |
display the OncoScore increment |
relative |
dispaly the incrementa as relative value |
main |
the title |
xlab |
description of x asix (defaul score) |
ylab |
description of y asix (defaul genes) |
legend.pos |
Position of the legend |
file |
where to save the plot |
... |
additional parameter to pass to the lines function |
A plot
data(query.timepoints) result = compute.oncoscore.timeseries(query.timepoints) plot.oncoscore.timeseries(result)data(query.timepoints) result = compute.oncoscore.timeseries(query.timepoints) plot.oncoscore.timeseries(result)
This dataset contains the result of perform.web.query on genes
data(query)data(query)
rdata
matrix 5 x 2
example data
This dataset contains the result of perform.time.series.query on genes and timepoints
data(query.timepoints)data(query.timepoints)
rdata
list of 5 matrix 5 x 2
example data
This dataset contains a list of time points to be used in the analysis as an example
data(timepoints)data(timepoints)
rdata
list of 5 elements
example data
try to query the given URL
try.scan(getURL)try.scan(getURL)
getURL |
The given URL |
Result obtained from PubMed